Struct codemap::Span
[−]
[src]
pub struct Span { /* fields omitted */ }A range of text within a CodeMap.
Methods
impl Span[src]
fn subspan(&self, begin: u64, end: u64) -> Span
Makes a span from offsets relative to the start of this span.
Panics
- If
end < begin - If
endis beyond the length of the span
fn contains(&self, other: Span) -> bool
Checks if a span is contained within this span.
fn low(&self) -> Pos
The position in the codemap representing the first byte of the span.
fn high(&self) -> Pos
The position after the last byte of the span.
fn len(&self) -> u64
The length in bytes of the text of the span